transliterate library
Constants
- bengali → const String
- Bengali script identifier.
- devanagari → const String
- Devanagari script identifier. Used as a scheme name in transliteration operations.
- grantha → const String
- Grantha script identifier.
- gujarati → const String
- Gujarati script identifier.
- gurmukhi → const String
- Gurmukhi (Punjabi) script identifier.
- hk → const String
- Harvard-Kyoto romanization scheme identifier.
- hkDravidian → const String
- Harvard-Kyoto Dravidian variant identifier.
- iast → const String
- International Alphabet of Sanskrit Transliteration (IAST) identifier.
- iso → const String
- ISO 15919 romanization scheme identifier.
- isoVedic → const String
- ISO 15919 Vedic variant identifier.
- itrans → const String
- ITRANS romanization scheme identifier.
- itransDravidian → const String
- ITRANS Dravidian variant identifier.
- kannada → const String
- Kannada script identifier.
- kolkata → const String
- Kolkata romanization scheme v2 identifier.
- kolkataV2 → const String
- Alias for kolkata_v2.
- malayalam → const String
- Malayalam script identifier.
- optitrans → const String
- Optitrans romanization scheme identifier.
- optitransDravidian → const String
- Optitrans Dravidian variant identifier.
- oriya → const String
- Oriya script identifier.
- slp1 → const String
- SLP1 (Sanskrit Library Project 1) romanization scheme identifier.
- tamil → const String
- Tamil script identifier.
- tamilSub → const String
- Tamil with subscripted numerals identifier.
- tamilSup → const String
- Tamil with superscripted numerals identifier.
- telugu → const String
- Telugu script identifier.
- titus → const String
- Titus romanization scheme identifier.
- velthuis → const String
- Velthuis romanization scheme identifier.
- wx → const String
- WX romanization scheme identifier.
Functions
-
detect(
String text) → String - Automatically detects the Indic script or romanization scheme of the given text.
-
getNumber(
String text) → String - Converts Indic numerals in text to IAST romanization numerals.
-
getStandardForm(
String data, String schemeName) → String - Converts text to the standard form for a given romanization scheme.
-
likelyDravidian(
String script) → bool - Checks if the given script is a Dravidian language script.
-
transliterate(
String data, {String? fromScheme, String? toScheme, SchemeMap? schemeMap, Map< String, String> togglers = const {}, Set<String> suspendOn = const {}, Set<String> suspendOff = const {}, String maybeUseDravidianVariant = 'no'}) → String - Transliterates text from one Indic script or romanization scheme to another.